durationtools.lilypond_duration_string_to_rational
==================================================

.. autofunction:: abjad.tools.durationtools.lilypond_duration_string_to_rational.lilypond_duration_string_to_rational
